from setuptools import setup

setup(
    name='NlpToolkit-NamedEntityRecognition',
    version='1.0.5',
    packages=['NamedEntityRecognition'],
    url='https://github.com/olcaytaner/TurkishNamedEntityRecognition-Py',
    license='',
    author='olcaytaner',
    author_email='olcaytaner@isikun.edu.tr',
    description='NER Corpus Processing Library',
    install_requires=['NlpToolkit-Corpus']
)
